@@ -20,7 +20,7 @@ if [ ! -d ${src} ] ; then
 	done
 fi
 if [ ! -d ${src} ] ; then
-	wget https://www.kernel.org/pub/linux/kernel/v3.x/linux-${ver}.tar.xz -P /usr/portage/distfiles/
+	wget https://www.kernel.org/pub/linux/kernel/v${ver:0:1}.x/linux-${ver}.tar.xz -P /usr/portage/distfiles/
 	exec "$0" "$@"
 fi
 
@@ -60,6 +60,11 @@ for a in ${arches} ; do
 		done
 	fi
 done
+# handle x86 unique cruft
+if [[ -e ${src}/arch/x86/entry/syscalls ]] ; then
+	mkdir -p ${dst}/arch/x86/entry
+	cp -r ${src}/arch/x86/entry/syscalls ${dst}/arch/x86/entry/
+fi
 # mips has some stupid unique bs
 if [[ -e ${src}/arch/mips/Kbuild.platforms ]] ; then
 	for f in "${src}"/arch/mips/*/Platform ; do
